@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2012-2018, Intel Corporation
+* Copyright (c) 2012-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -29,6 +29,7 @@
 #include "codechal_secure_decode_interface.h"
 #include "codechal_decode_vp9.h"
 #include "codechal_mmc_decode_vp9.h"
+#include "hal_oca_interface.h"
 #if USE_CODECHAL_DEBUG_TOOL
 #include <sstream>
 #include <fstream>
@@ -163,17 +164,29 @@ CodechalDecodeVp9 ::CodechalDecodeVp9(
     CodechalHwInterface *   hwInterface,
     CodechalDebugInterface *debugInterface,
     PCODECHAL_STANDARD_INFO standardInfo) : CodechalDecode(hwInterface, debugInterface, standardInfo),
+                                            m_usFrameWidthAlignedMinBlk(0),
+                                            m_usFrameHeightAlignedMinBlk(0),
+                                            m_vp9DepthIndicator(0),
+                                            m_chromaFormatinProfile(0),
+                                            m_dataSize(0),
+                                            m_dataOffset(0),
+                                            m_frameCtxIdx(0),
                                             m_curMvTempBufIdx(0),
                                             m_colMvTempBufIdx(0),
                                             m_copyDataBufferSize(0),
+                                            m_copyDataOffset(0),
                                             m_copyDataBufferInUse(false),
+                                            m_hcpDecPhase(0),
                                             m_prevFrmWidth(0),
                                             m_prevFrmHeight(0),
                                             m_allocatedWidthInSb(0),
                                             m_allocatedHeightInSb(0),
                                             m_mvBufferSize(0),
+                                            m_resetSegIdBuffer(false),
                                             m_pendingResetPartial(0),
-                                            m_saveInterProbs(0)
+                                            m_saveInterProbs(0),
+                                            m_fullProbBufferUpdate(false),
+                                            m_dmemBufferSize(0)
 {
     CODECHAL_DECODE_FUNCTION_ENTER;
 
@@ -197,9 +210,20 @@ CodechalDecodeVp9 ::CodechalDecodeVp9(
     MOS_ZeroMemory(&m_resSegmentIdBuffReset, sizeof(m_resSegmentIdBuffReset));
     MOS_ZeroMemory(&m_resHucSharedBuffer, sizeof(m_resHucSharedBuffer));
     MOS_ZeroMemory(&m_picMhwParams, sizeof(m_picMhwParams));
+    MOS_ZeroMemory(&m_destSurface, sizeof(m_destSurface));
+    MOS_ZeroMemory(&m_lastRefSurface, sizeof(m_lastRefSurface));
+    MOS_ZeroMemory(&m_goldenRefSurface, sizeof(m_goldenRefSurface));
+    MOS_ZeroMemory(&m_altRefSurface, sizeof(m_altRefSurface));
+    MOS_ZeroMemory(&m_resDataBuffer, sizeof(m_resDataBuffer));
+    MOS_ZeroMemory(&m_resCoefProbBuffer, sizeof(m_resCoefProbBuffer));
+    MOS_ZeroMemory(&m_resSyncObject, sizeof(m_resSyncObject));
+    MOS_ZeroMemory(&m_resSyncObjectWaContextInUse, sizeof(m_resSyncObjectWaContextInUse));
+    MOS_ZeroMemory(&m_resSyncObjectVideoContextInUse, sizeof(m_resSyncObjectVideoContextInUse));
 
     m_prevFrameParams.value = 0;
-
+#if (_DEBUG || _RELEASE_INTERNAL)
+    m_reportFrameCrc        = true;
+#endif
     for (uint8_t i = 0; i < CODEC_VP9_NUM_CONTEXTS; i++)
     {
         m_pendingResetFullTables[i] = 0;
@@ -569,9 +593,9 @@ MOS_STATUS CodechalDecodeVp9 :: AllocateResourcesFixedSizes()
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnCreateSyncResource(
         m_osInterface, &m_resSyncObjectVideoContextInUse));
 
-    CodecHalAllocateDataList(
+    CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalAllocateDataList(
         m_vp9RefList,
-        CODECHAL_NUM_UNCOMPRESSED_SURFACE_VP9);
+        CODECHAL_NUM_UNCOMPRESSED_SURFACE_VP9));
 
     // VP9 Probability buffer
     for (uint8_t i = 0; i < CODEC_VP9_NUM_CONTEXTS + 1; i++)
@@ -1052,7 +1076,7 @@ MOS_STATUS CodechalDecodeVp9 :: CheckAndCopyBitStream()
             (m_vp9PicParams->FrameWidthMinus1 + 1) * (m_vp9PicParams->FrameHeightMinus1 + 1) * 6;
     }
 
-    if (m_firstExecuteCall) // first exec call
+    if (IsFirstExecuteCall()) // first exec call
     {
         if (m_dataSize < m_vp9PicParams->BSBytesInBuffer)  // Current bitstream buffer is not big enough
         {
@@ -1122,6 +1146,7 @@ MOS_STATUS CodechalDecodeVp9::SetFrameStates ()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
+    PERF_UTILITY_AUTO(__FUNCTION__, PERF_DECODE, PERF_LEVEL_HAL);
     CODECHAL_DECODE_FUNCTION_ENTER;
 
     CODECHAL_DECODE_CHK_NULL_RETURN(m_decodeParams.m_destSurface);
@@ -1142,7 +1167,7 @@ MOS_STATUS CodechalDecodeVp9::SetFrameStates ()
         m_resCoefProbBuffer = *(m_decodeParams.m_coefProbBuffer);
     }
 
-    if (m_firstExecuteCall)
+    if (IsFirstExecuteCall())
     {
         CODECHAL_DECODE_CHK_STATUS_RETURN(InitializeBeginFrame());
     }
@@ -1473,7 +1498,9 @@ MOS_STATUS CodechalDecodeVp9 :: InitPicStateMhwParams()
         }
     }
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetPipeBufAddr(m_picMhwParams.PipeBufAddrParams));
+#endif
 
     if (m_streamOutEnabled)
     {
@@ -1481,9 +1508,11 @@ MOS_STATUS CodechalDecodeVp9 :: InitPicStateMhwParams()
             &(m_streamOutBuffer[m_streamOutCurrBufIdx]);
     }
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->CheckReferenceList(m_picMhwParams.PipeBufAddrParams));
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetRefrenceSync(m_disableDecodeSyncLock, m_disableLockForTranscode));
+#endif
 
     m_picMhwParams.PipeBufAddrParams->presMfdDeblockingFilterRowStoreScratchBuffer =
         &m_resDeblockingFilterLineRowStoreScratchBuffer;
@@ -1680,6 +1709,7 @@ MOS_STATUS CodechalDecodeVp9 :: DecodeStateLevel()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
+    PERF_UTILITY_AUTO(__FUNCTION__, PERF_DECODE, PERF_LEVEL_HAL);
     CODECHAL_DECODE_FUNCTION_ENTER;
 
     if (m_secureDecoder && m_hcpDecPhase == CodechalHcpDecodePhaseInitialized)
@@ -1696,6 +1726,9 @@ MOS_STATUS CodechalDecodeVp9 :: DecodeStateLevel()
         &cmdBuffer,
         0));
 
+    auto mmioRegisters = m_hwInterface->GetMfxInterface()->GetMmioRegisters(m_vdboxIndex);
+    HalOcaInterface::On1stLevelBBStart(cmdBuffer, *m_osInterface->pOsContext, m_osInterface->CurrentGpuContextHandle, *m_miInterface, *mmioRegisters);
+
     //Frame tracking functionality is called at the start of a command buffer.
     //Called at FE decode phase, since BE decode phase will only construct BE batch buffers.
     CODECHAL_DECODE_CHK_STATUS_RETURN(SendPrologWithFrameTracking(
@@ -1722,6 +1755,8 @@ MOS_STATUS CodechalDecodeVp9 :: DecodePrimitiveLevel()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
+    PERF_UTILITY_AUTO(__FUNCTION__, PERF_DECODE, PERF_LEVEL_HAL);
+
     CODECHAL_DECODE_FUNCTION_ENTER;
 
     // Bitstream is incomplete, don't do any decoding work.
@@ -1861,6 +1896,8 @@ MOS_STATUS CodechalDecodeVp9 :: DecodePrimitiveLevel()
 
     uint32_t renderingFlags = m_videoContextUsesNullHw;
 
+    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface);
+
     //submit command buffer
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(
         m_osInterface,
@@ -2477,59 +2514,3 @@ MOS_STATUS CodechalDecodeVp9::ContextBufferInit(
         return MOS_STATUS_SUCCESS;
     }
 }
-
-MOS_STATUS CodechalDecodeVp9::SetCencBatchBuffer(
-    PMOS_COMMAND_BUFFER cmdBuffer)
-{
-    CODECHAL_DECODE_CHK_NULL_RETURN(cmdBuffer);
-
-    MHW_BATCH_BUFFER        batchBuffer;
-    MOS_ZeroMemory(&batchBuffer, sizeof(MHW_BATCH_BUFFER));
-    MOS_RESOURCE *resHeap = nullptr;
-    CODECHAL_DECODE_CHK_NULL_RETURN(resHeap = m_cencBuf->secondLvlBbBlock->GetResource());
-    batchBuffer.OsResource   = *resHeap;
-    batchBuffer.dwOffset     = m_cencBuf->secondLvlBbBlock->GetOffset() + VP9_CENC_PRIMITIVE_CMD_OFFSET_IN_DW * 4;
-    batchBuffer.iSize        = m_cencBuf->secondLvlBbBlock->GetSize() - VP9_CENC_PRIMITIVE_CMD_OFFSET_IN_DW * 4;
-    batchBuffer.bSecondLevel = true;
-#if (_DEBUG || _RELEASE_INTERNAL)
-    batchBuffer.iLastCurrent = batchBuffer.iSize;
-#endif  // (_DEBUG || _RELEASE_INTERNAL)
-
-    CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiBatchBufferStartCmd(
-        cmdBuffer,
-        &batchBuffer));
-
-    CODECHAL_DEBUG_TOOL(
-        CODECHAL_DECODE_CHK_STATUS_RETURN(m_debugInterface->Dump2ndLvlBatch(
-            &batchBuffer,
-            CODECHAL_NUM_MEDIA_STATES,
-            "_2ndLvlBatch_Pic_Cmd"));)
-
-    batchBuffer.dwOffset     = m_cencBuf->secondLvlBbBlock->GetOffset();
-    batchBuffer.iSize        = VP9_CENC_PRIMITIVE_CMD_OFFSET_IN_DW * 4;
-    batchBuffer.bSecondLevel = true;
-#if (_DEBUG || _RELEASE_INTERNAL)
-    batchBuffer.iLastCurrent = batchBuffer.iSize;
-#endif  // (_DEBUG || _RELEASE_INTERNAL)
-
-    CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiBatchBufferStartCmd(
-        cmdBuffer,
-        &batchBuffer));
-
-    CODECHAL_DEBUG_TOOL(
-        CODECHAL_DECODE_CHK_STATUS_RETURN(m_debugInterface->Dump2ndLvlBatch(
-            &batchBuffer,
-            CODECHAL_NUM_MEDIA_STATES,
-            "_2ndLvlBatch_Primitive_Cmd"));)
-
-    // Update GlobalCmdBufId
-    MHW_MI_STORE_DATA_PARAMS miStoreDataParams;
-    MOS_ZeroMemory(&miStoreDataParams, sizeof(miStoreDataParams));
-    miStoreDataParams.pOsResource = m_cencBuf->resTracker;
-    miStoreDataParams.dwValue     = m_cencBuf->trackerId;
-    CODECHAL_DECODE_VERBOSEMESSAGE("dwCmdBufId = %d", miStoreDataParams.dwValue);
-    CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiStoreDataImmCmd(
-        cmdBuffer,
-        &miStoreDataParams));
-    return MOS_STATUS_SUCCESS;
-}
