@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2020, Intel Corporation
+* Copyright (c) 2011-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -168,6 +168,10 @@ struct CodechalDecodeStatusReport
 #if (_DEBUG || _RELEASE_INTERNAL)
     //! \brief Applies when debug dumps are enabled, pointer to SFC output resource for the picture associated with this status report
     PMOS_RESOURCE           m_currSfcOutputPicRes = nullptr;
+    //! \brief Applies when debug dumps are enabled, pointer to histogram output resource for the picture associated with this status report
+    PMOS_RESOURCE           m_currHistogramOutBuf = nullptr;
+    //! \brief Applies when debug dumps are enabled, pointer to AV1 film grain output resource for the picture associated with this status report
+    PMOS_RESOURCE           m_currFgOutputPicRes = nullptr;
     //! \brief Applies when debug dumps are enabled, stream out buffer
     PMOS_RESOURCE           m_streamOutBuf = nullptr;
     //! \brief Applies when debug dumps are enabled, index of the streamout buffer
@@ -398,6 +402,8 @@ public:
         MOS_FORMAT format = Format_NV12,
         bool isCompressible = false);
 
+    MOS_STATUS DestroySurface(PMOS_SURFACE surface);
+
     //!
     //! \brief  Entry to allocate and intialize the decode instance
     //! \param  [in] codecHalSettings
@@ -672,6 +678,8 @@ public:
     //!
     bool IsDecoderMmcEnabled(){return m_mmc ? m_mmc->IsMmcEnabled() : false;}
 
+    MOS_STATUS CheckDecodeOutputBufSize(MOS_SURFACE &dstSurface);
+
 protected:
 
     //!
@@ -901,6 +909,8 @@ private:
         uint32_t allocWidth,
         uint32_t allocHeight,
         MOS_FORMAT format);
+
+    bool isSyncFreeNeededForMMCSurface(PMOS_SURFACE surface);
     //!
     //! \brief    Resize specific reference surfaces
     //! \details  Resize specific reference surfaces for decode downsampling for all codec types
@@ -920,6 +930,17 @@ private:
         uint32_t     width,
         uint32_t     height,
         MOS_FORMAT   format);
+
+   //!
+   //! \brief    Allocate Decode Output Buffer
+   //! \details  To Allocate Decode Output Buffer for media debug hook.
+   //! \param    dstSurface
+   //!           Decoded dstSurface
+   //! \return   MOS_STATUS
+   //!           MOS_STATUS_SUCCESS if success, else fail reason
+   //!
+   MOS_STATUS AllocateDecodeOutputBuf();
+
     //!
     //! \brief    Deallocate specific reference surfaces
     //! \details  Deallocate specific reference surfaces for decode downsampling for all codec types
@@ -1078,11 +1099,17 @@ protected:
     //! \brief Internal buffer for predication
     MOS_RESOURCE               m_predicationBuffer = { 0 };
 
+    MOS_RESOURCE               m_frameCountTypeBuf = { 0 };
+
+    MOS_RESOURCE               m_crcBuf = { 0 };
+
 #if (_DEBUG || _RELEASE_INTERNAL)
     //! \brief Downsampled surfaces
     PMOS_SURFACE                m_downsampledSurfaces = nullptr;
 #endif
+    uint8_t*                    m_decodeOutputBuf = nullptr;
 
+    uint32_t                    m_decodeOutputBufSize = 0;
     //! \brief    Decode histogram interface
     //! \details  Support YUV Luma histogram.
     CodechalDecodeHistogram    *m_decodeHistogram = nullptr;
