@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2020, Intel Corporation
+* Copyright (c) 2009-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -104,6 +104,14 @@ extern "C" {
     (((rect1).left  <= (rect2).left)  && ((rect1).top    <= (rect2).top) &&     \
      ((rect1).right >= (rect2).right) && ((rect1).bottom >= (rect2).bottom))
 
+//!
+//! \def RECT1_CONTAINS_RECT2_ONEPIXELBIAS(rect1, rect2)
+//! Compare if rectangle \a rect1 contains rectangle \a rect2 in coordinate, One pixel bias is allowed
+//!
+#define RECT1_CONTAINS_RECT2_ONEPIXELBIAS(rect1, rect2)                                    \
+    (((rect1).left  <= ((rect2).left + 1))  && ((rect1).top    <= ((rect2).top + 1)) &&  \
+     (((rect1).right + 1) >= (rect2).right) && (((rect1).bottom + 1) >= (rect2).bottom))
+
 //!
 //! \def RECT1_OUTSIDE_RECT2(rect1, rect2)
 //! Compare if the rectangle \a rect1 is outside the rectangle \a rect2 at least partly in coordinate
@@ -207,7 +215,7 @@ extern "C" {
 #define NLAS_NONLINEARCROP_DEFAULT    0.0F
 #define NLAS_NONLINEARCROP_STEP       0.001F
 
-#define VPHAL_MAX_SOURCES               17       //!< worst case: 16 sub-streams + 1 pri video
+#define VPHAL_MAX_SOURCES               65       //!< worst case: 64 sub-streams + 1 pri video
 #define VPHAL_MAX_CHANNELS              2
 #define VPHAL_MAX_TARGETS               8        //!< multi output support
 #define VPHAL_MAX_FUTURE_FRAMES         18       //!< maximum future frames supported in VPHAL
@@ -507,6 +515,16 @@ typedef enum _VPHAL_DI_MODE
 } VPHAL_DI_MODE;
 C_ASSERT(DI_MODE_ADI == 1);         //!< When adding, update assert & vphal_solo_scenario.cpp
 
+//!
+//! \ brief HVS DN Mode enum
+//!
+typedef enum _VPHAL_HVSDN_MODE
+{
+    HVSDENOISE_AUTO_BDRATE = 0,
+    HVSDENOISE_AUTO_SUBJECTIVE,
+    HVSDENOISE_MANUAL
+} VPHAL_HVSDN_MODE;
+
 //!
 //! \brief Blend Type enum
 //!
@@ -536,7 +554,7 @@ C_ASSERT(VPHAL_SCALING_ADV_QUALITY == 3);   //!< When adding, update assert & vp
 
 typedef enum _VPHAL_SCALING_PREFERENCE
 {
-    VPHAL_SCALING_PREFER_SFC,          // SFC is default
+    VPHAL_SCALING_PREFER_SFC = 0,      // SFC is default
     VPHAL_SCALING_PREFER_COMP,         // For Gen9/10, Composition AVS get better quality than SFC AVS
     VPHAL_SCALING_PREFER_SFC_FOR_VEBOX // if VEBOX is required, use VEBOX + SFC, otherwise use Composistion
 } VPHAL_SCALING_PREFERENCE;
@@ -652,6 +670,8 @@ typedef enum _VPHAL_OUTPUT_PIPE_MODE
 typedef struct _RENDERHAL_INTERFACE     *PRENDERHAL_INTERFACE;
 typedef class MhwVeboxInterface         *PMHW_VEBOX_INTERFACE;
 typedef class MhwSfcInterface           *PMHW_SFC_INTERFACE;
+typedef struct VPHAL_SURFACE            *PVPHAL_SURFACE;
+
 class VphalRenderer;
 
 class MhwCpInterface;
@@ -856,10 +876,20 @@ C_ASSERT(NOISELEVEL_VC1_HD == 1); //!< When adding, update assert & vphal_solo_s
 //!
 typedef struct _VPHAL_HVSDENOISE_PARAMS
 {
-    uint16_t            QP;
-    uint16_t            Strength;
-    void*               pHVSDenoiseParam;
-    uint32_t            dwDenoiseParamSize;
+    uint16_t            QP                  = 0;
+    uint16_t            Strength            = 0;
+    VPHAL_HVSDN_MODE    Mode                = HVSDENOISE_AUTO_BDRATE;
+    void*               pHVSDenoiseParam    = nullptr;
+    uint32_t            dwDenoiseParamSize  = 0;
+    uint32_t            dwGlobalNoiseLevel  = 0;  //!< Global Noise Level for Y
+    uint32_t            dwGlobalNoiseLevelU = 0;  //!< Global Noise Level for U
+    uint32_t            dwGlobalNoiseLevelV = 0;  //!< Global Noise Level for V
+    uint16_t            TgneEnable          = 0;
+    uint16_t            FirstFrame          = 0;
+    uint16_t            TgneFirstFrame      = 0;
+    uint16_t            Fallback            = 0;
+    uint16_t            EnableChroma        = 0;
+    uint16_t            EnableTemporalGNE   = 0;
 } VPHAL_HVSDENOISE_PARAMS, *PVPHAL_HVSDENOISE_PARAMS;
 
 //!
@@ -878,15 +908,15 @@ typedef struct _VPHAL_SLIMIPU_DENOISE_PARAM
 //!
 typedef struct _VPHAL_DENOISE_PARAMS
 {
-    bool                                bEnableChroma;
-    bool                                bEnableLuma;
-    bool                                bAutoDetect;
-    float                               fDenoiseFactor;
-    VPHAL_NOISELEVEL                    NoiseLevel;
-    bool                                bEnableHVSDenoise;
-    VPHAL_HVSDENOISE_PARAMS             HVSDenoise;
-    bool                                bEnableSlimIPUDenoise;
-    VPHAL_SLIMIPU_DENOISE_PARAM         SlimIPUDenoise;
+    bool                                bEnableChroma  = false;
+    bool                                bEnableLuma    = false;
+    bool                                bAutoDetect    = false;
+    float                               fDenoiseFactor = 0.0;
+    VPHAL_NOISELEVEL                    NoiseLevel     = NOISELEVEL_DEFAULT;
+    bool                                bEnableHVSDenoise = false;
+    VPHAL_HVSDENOISE_PARAMS             HVSDenoise        = {};
+    bool                                bEnableSlimIPUDenoise = false;
+    VPHAL_SLIMIPU_DENOISE_PARAM         SlimIPUDenoise        = {};
 } VPHAL_DENOISE_PARAMS, *PVPHAL_DENOISE_PARAMS;
 
 //!
@@ -928,11 +958,33 @@ typedef struct _VPHAL_COLORPIPE_PARAMS
     VPHAL_TCC_PARAMS    TccParams;
 } VPHAL_COLORPIPE_PARAMS, *PVPHAL_COLORPIPE_PARAMS;
 
+//!
+//! \brief Vphal 3DLUT Channel Mapping enum
+//!
+typedef enum _VPHAL_3DLUT_CHANNEL_MAPPING
+{
+    CHANNEL_MAPPING_RGB_RGB          = 0,
+    CHANNEL_MAPPING_YUV_RGB          = 1 << 0,
+    CHANNEL_MAPPING_VUY_RGB          = 1 << 1,
+} VPHAL_3DLUT_CHANNEL_MAPPING;
+
+//!
+//! Structure VPHAL_3DLUT_PARAMS
+//! \brief 3DLUT parameters - 3DLUT
+//!
+typedef struct _VPHAL_3DLUT_PARAMS
+{
+    PVPHAL_SURFACE             pExt3DLutSurface;          // Pointer to the 3DLUT surface which app passes to driver.
+    uint32_t                   LutSize;                   // Size of 3DLUT, i.e, how many entries LUT has.
+    uint32_t                   ChannelMapping;            // Channel Mapping for the 3DLUT input to 3DLUT output.
+    uint16_t                   BitDepthPerChannel;        // Bit Depth Per Channel(4 channels for 3DLUT).
+    uint16_t                   ByteCountPerEntry;         // Byte Count Per Entry including reserved bytes.
+} VPHAL_3DLUT_PARAMS, * PVPHAL_3DLUT_PARAMS;
+
 //!
 //! Structure VPHAL_SURFACE
 //! \brief DDI-VPHAL surface definition
 //!
-typedef struct VPHAL_SURFACE           *PVPHAL_SURFACE;
 struct VPHAL_SURFACE
 {
     // Color Information
@@ -1030,6 +1082,9 @@ struct VPHAL_SURFACE
     PVPHAL_HDR_PARAMS           pHDRParams = nullptr;
     VPHAL_GAMMA_TYPE            GammaType = VPHAL_GAMMA_NONE;    //!<Gamma Type
     bool                        bPreAPGWorkloadEnable = false;   //!< Previous Surface Execution Path
+
+    // 3DLUT parameters
+    PVPHAL_3DLUT_PARAMS         p3DLutParams = nullptr;          //!< 3DLut Mapping Params
 };
 
 //!
@@ -1066,6 +1121,8 @@ typedef struct _VPHAL_COLORFILL_PARAMS
     bool                bYCbCr;
     uint32_t            Color;
     VPHAL_CSPACE        CSpace;
+    bool                bDisableColorfillinSFC;
+    bool                bOnePixelBiasinSFC;
 } VPHAL_COLORFILL_PARAMS, *PVPHAL_COLORFILL_PARAMS;
 
 //!
@@ -1178,6 +1235,7 @@ struct VPHAL_RENDER_PARAMS
     bool                                    bDisableVeboxFor8K = false;
     bool                                    bUseVEHdrSfc       = false;  // use SFC for to perform CSC/Scaling/RGBSwap of HDR streaming; if false, use composite render.
     bool                                    bNonFirstFrame     = false;  // first frame or not: first frame false, otherwise true considering zeromemory parameters.
+    bool                                    bOptimizeCpuTiming = false;  //!< Optimize Cpu Timing
 
     VPHAL_RENDER_PARAMS() :
         uSrcCount(0),
@@ -1340,6 +1398,10 @@ MOS_STATUS VpHal_GetSurfaceInfo(
 //!           true if allocated, false for not
 //! \param    [in] resUsageType
 //!           resource usage type for caching
+//! \param    [in] tileModeByForce
+//!           Forced tile mode
+//! \param    [in] memType
+//!           vidoe memory location
 //! \return   MOS_STATUS
 //!           MOS_STATUS_SUCCESS if success. Error code otherwise
 //!
@@ -1356,7 +1418,9 @@ MOS_STATUS VpHal_ReAllocateSurface(
     MOS_RESOURCE_MMC_MODE   CompressionMode,                                    // [in]    Compression mode
     bool*                   pbAllocated,                                        // [out]   Flag indicating new allocation
     MOS_HW_RESOURCE_DEF     resUsageType = MOS_HW_RESOURCE_DEF_MAX,             // [in]    resource usage type
-    MOS_TILE_MODE_GMM       tileModeByForce = MOS_TILE_UNSET_GMM);              // [in]    Flag to indicate if GMM flag tile64 need set
+    MOS_TILE_MODE_GMM       tileModeByForce = MOS_TILE_UNSET_GMM,               // [in]    Flag to indicate if GMM flag tile64 need set
+    Mos_MemPool             memType = MOS_MEMPOOL_VIDEOMEMORY,                  // [in]    Flag to indicate the memType
+    bool                    isNotLockable = false);                             // [in]    Flag to indicate whether resource being not lockable
 
 //!
 //! \brief    Reads the Surface contents and copy to the Dst Buffer
@@ -1504,6 +1568,73 @@ void VpHal_AllocParamsInitType(
 MOS_SURFACE VpHal_ConvertVphalSurfaceToMosSurface(
     PVPHAL_SURFACE pSurface);
 
+bool IsSyncFreeNeededForMMCSurface(PVPHAL_SURFACE pSurface, PMOS_INTERFACE pOsInterface);
+
+//!
+//! \brief  VEBOX IECP parameters
+//!
+class VPHAL_VEBOX_IECP_PARAMS
+{
+public:
+    PVPHAL_COLORPIPE_PARAMS         pColorPipeParams;
+    PVPHAL_PROCAMP_PARAMS           pProcAmpParams;
+    MOS_FORMAT                      dstFormat;
+    MOS_FORMAT                      srcFormat;
+
+    // CSC params
+    bool                            bCSCEnable;                                 // Enable CSC transform
+    float*                          pfCscCoeff;                                 // [3x3] CSC Coeff matrix
+    float*                          pfCscInOffset;                              // [3x1] CSC Input Offset matrix
+    float*                          pfCscOutOffset;                             // [3x1] CSC Output Offset matrix
+    bool                            bAlphaEnable;                               // Alpha Enable Param
+    uint16_t                        wAlphaValue;                                // Color Pipe Alpha Value
+
+    // Front End CSC params
+    bool                            bFeCSCEnable;                               // Enable Front End CSC transform
+    float*                          pfFeCscCoeff;                               // [3x3] Front End CSC Coeff matrix
+    float*                          pfFeCscInOffset;                            // [3x1] Front End CSC Input Offset matrix
+    float*                          pfFeCscOutOffset;                           // [3x1] Front End CSC Output Offset matrix
+
+    VPHAL_VEBOX_IECP_PARAMS()
+    {
+        pColorPipeParams    = nullptr;
+        pProcAmpParams      = nullptr;
+        dstFormat           = Format_Any;
+        srcFormat           = Format_Any;
+        bCSCEnable          = false;
+        pfCscCoeff          = nullptr;
+        pfCscInOffset       = nullptr;
+        pfCscOutOffset      = nullptr;
+        bAlphaEnable        = false;
+        wAlphaValue         = 0;
+
+        bFeCSCEnable        = false;
+        pfFeCscCoeff        = nullptr;
+        pfFeCscInOffset     = nullptr;
+        pfFeCscOutOffset    = nullptr;
+    }
+    virtual ~VPHAL_VEBOX_IECP_PARAMS()
+    {
+        pColorPipeParams    = nullptr;
+        pProcAmpParams      = nullptr;
+    }
+    virtual void Init()
+    {
+        pColorPipeParams    = nullptr;
+        pProcAmpParams      = nullptr;
+
+        dstFormat           = Format_Any;
+        srcFormat           = Format_Any;
+
+        bCSCEnable          = false;
+        pfCscCoeff          = nullptr;
+        pfCscInOffset       = nullptr;
+        pfCscOutOffset      = nullptr;
+        bAlphaEnable        = false;
+        wAlphaValue         = 0;
+    }
+    virtual void   *GetExtParams() { return nullptr; }
+};
 #ifdef __cplusplus
 }
 #endif
