@@ -68,6 +68,7 @@
 MOS_STATUS  MosOcaInterfaceSpecific::s_ocaStatus          = MOS_STATUS_SUCCESS;
 uint32_t MosOcaInterfaceSpecific::s_lineNumForOcaErr      = 0;
 bool MosOcaInterfaceSpecific::s_bOcaStatusExistInReg      = false;
+int32_t MosOcaInterfaceSpecific::s_refCount               = 0;
 
 //!
 //! \brief  Get the idle oca buffer, which is neither used by hw nor locked, and lock it for edit.
@@ -378,7 +379,7 @@ MOS_STATUS MosOcaInterfaceSpecific::AddResourceToDumpList(MOS_OCA_BUFFER_HANDLE
     {
         resMmcMode = MOS_MEMCOMP_DISABLED;
     }
-
+    m_ocaBufContextList[ocaBufHandle].logSection.resInfo.resInfoList[i].gfxAddress               = MosInterface::GetResourceGfxAddress(&steamState, &resource);
     m_ocaBufContextList[ocaBufHandle].logSection.resInfo.resInfoList[i].sizeAllocation           = resource.pGmmResInfo->GetSizeAllocation();
     m_ocaBufContextList[ocaBufHandle].logSection.resInfo.resInfoList[i].sizeSurface              = resource.pGmmResInfo->GetSizeSurface();
     m_ocaBufContextList[ocaBufHandle].logSection.resInfo.resInfoList[i].sizeSurfacePhy           = resource.pGmmResInfo->GetSizeSurface();
@@ -465,7 +466,7 @@ MOS_STATUS MosOcaInterfaceSpecific::DumpDataBlock(MOS_OCA_BUFFER_HANDLE ocaBufHa
     {
         return MOS_STATUS_SUCCESS; 
     }
-    if (ocaBufHandle > MAX_NUM_OF_OCA_BUF_CONTEXT || nullptr == pHeader)
+    if (ocaBufHandle >= MAX_NUM_OF_OCA_BUF_CONTEXT || nullptr == pHeader)
     {
         return MOS_STATUS_INVALID_PARAMETER;
     }
@@ -493,13 +494,13 @@ MOS_STATUS MosOcaInterfaceSpecific::DumpDataBlock(MOS_OCA_BUFFER_HANDLE ocaBufHa
     {
         return MOS_STATUS_NOT_ENOUGH_BUFFER;
     }
-    m_ocaBufContextList[ocaBufHandle].logSection.offset += copySize;
 
     MOS_OS_CHK_STATUS_RETURN(InsertData(ocaBufHandle, (uint8_t *)pHeader, pHeader->m_HeaderSize));
     if (pHeader->m_DataSize > 0)
     {
         MOS_OS_CHK_STATUS_RETURN(InsertData(ocaBufHandle, (uint8_t *)pData, pHeader->m_DataSize));
     }
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -511,9 +512,8 @@ MOS_STATUS MosOcaInterfaceSpecific::InsertData(MOS_OCA_BUFFER_HANDLE ocaBufHandl
     }
 
     uint32_t sizeCpy = std::min(m_ocaLogSectionSizeLimit - m_ocaBufContextList[ocaBufHandle].logSection.offset, size);
-
     MOS_OS_CHK_STATUS_RETURN(MOS_SecureMemcpy((uint8_t *)m_ocaBufContextList[ocaBufHandle].logSection.base + m_ocaBufContextList[ocaBufHandle].logSection.offset, sizeCpy, p, sizeCpy));
-
+    m_ocaBufContextList[ocaBufHandle].logSection.offset += sizeCpy;
     return MOS_STATUS_SUCCESS;
 }
 
@@ -646,12 +646,10 @@ void MosOcaInterfaceSpecific::Initialize()
             return;
         }
         m_config.maxResInfoCount = OCA_MAX_RESOURCE_INFO_COUNT_MAX;
-        //m_resInfoPool = MOS_NewArray(MOS_OCA_RESOURCE_INFO, m_config.maxResInfoCount * MAX_NUM_OF_OCA_BUF_CONTEXT);
-        m_resInfoPool = new MOS_OCA_RESOURCE_INFO[m_config.maxResInfoCount * MAX_NUM_OF_OCA_BUF_CONTEXT];
+        m_resInfoPool = MOS_NewArray(MOS_OCA_RESOURCE_INFO, m_config.maxResInfoCount * MAX_NUM_OF_OCA_BUF_CONTEXT);
         if (nullptr == m_resInfoPool)
         {
-            delete []m_resInfoPool;
-            // MOS_DeleteArray(m_resInfoPool);
+            MOS_DeleteArray(m_resInfoPool);
             return;
         }
         MosUtilities::MosZeroMemory(m_resInfoPool, sizeof(MOS_OCA_RESOURCE_INFO)*m_config.maxResInfoCount * MAX_NUM_OF_OCA_BUF_CONTEXT);
@@ -664,17 +662,7 @@ void MosOcaInterfaceSpecific::Initialize()
             return;
         }
 
-        m_ocaMutex = (PMOS_MUTEX)malloc(sizeof(MOS_MUTEX));
-        if (m_ocaMutex != nullptr)
-        {
-            if (pthread_mutex_init(m_ocaMutex, nullptr))
-            {
-                free(m_ocaMutex);
-                m_ocaMutex = nullptr;
-                return;
-            }
-        }
-
+        m_ocaMutex = MosUtilities::MosCreateMutex();
         if (nullptr == m_ocaMutex)
         {
             return;
@@ -717,13 +705,12 @@ void MosOcaInterfaceSpecific::Uninitialize()
     {
         if (nullptr != m_ocaMutex)
         {
-            pthread_mutex_destroy(m_ocaMutex);
-            free(m_ocaMutex);
+            MosUtilities::MosDestroyMutex(m_ocaMutex);
             m_ocaMutex = nullptr;
         }
         if (m_resInfoPool != nullptr)
         {
-            delete []m_resInfoPool;
+            MOS_DeleteArray(m_resInfoPool);
             m_resInfoPool = nullptr;
             for (int i = 0; i < MAX_NUM_OF_OCA_BUF_CONTEXT; ++i)
             {
@@ -739,8 +726,12 @@ void MosOcaInterfaceSpecific::Uninitialize()
 //!
 void MosOcaInterfaceSpecific::InitInterface()
 {
-    MosOcaInterfaceSpecific &ins = (MosOcaInterfaceSpecific&)MosOcaInterfaceSpecific::GetInstance();
-    ins.Initialize();
+    if (MosUtilities::MosAtomicIncrement(&s_refCount) == 1)
+    {
+        MosOcaInterfaceSpecific &ins = (MosOcaInterfaceSpecific &)MosOcaInterfaceSpecific::GetInstance();
+        ins.Initialize();
+    }
+    return;
 }
 
 //!
@@ -748,7 +739,11 @@ void MosOcaInterfaceSpecific::InitInterface()
 //!
 void MosOcaInterfaceSpecific::UninitInterface()
 {
-    MosOcaInterfaceSpecific &ins = (MosOcaInterfaceSpecific&)MosOcaInterfaceSpecific::GetInstance();
-    ins.Uninitialize();
+    if (MosUtilities::MosAtomicDecrement(&s_refCount) == 0)
+    {
+        MosOcaInterfaceSpecific &ins = (MosOcaInterfaceSpecific &)MosOcaInterfaceSpecific::GetInstance();
+        ins.Uninitialize();
+    }
+    return;
 }
 
