@@ -140,27 +140,90 @@ class Impl : public Itf, public mhw::Impl
     _VDENC_CMD_DEF(_MHW_CMD_ALL_DEF_FOR_IMPL);
 
 public:
-    MOS_STATUS EnableVdencRowstoreCacheIfSupported(uint32_t address) override
+    MOS_STATUS SetRowstoreCachingOffsets(const RowStorePar &par) override
     {
         MHW_FUNCTION_ENTER;
 
-        if (this->m_vdencRowStoreCache.supported)
+        switch (par.mode)
         {
-            this->m_vdencRowStoreCache.enabled   = true;
-            this->m_vdencRowStoreCache.dwAddress = address;
+        case RowStorePar::AVC:
+        {
+            if (this->m_rowStoreCache.vdenc.supported)
+            {
+                this->m_rowStoreCache.vdenc.enabled   = true;
+                this->m_rowStoreCache.vdenc.dwAddress = !par.isField ? 1280 : 1536;
+            }
+            if (this->m_rowStoreCache.ipdl.supported)
+            {
+                this->m_rowStoreCache.ipdl.enabled   = true;
+                this->m_rowStoreCache.ipdl.dwAddress = 512;
+            }
+
+            break;
         }
-
-        return MOS_STATUS_SUCCESS;
-    }
-
-    MOS_STATUS EnableVdencRowIpdlstoreCacheIfSupported(uint32_t address) override
-    {
-        MHW_FUNCTION_ENTER;
-
-        if (this->m_vdencIpdlRowstoreCache.supported)
+        case RowStorePar::HEVC:
         {
-            this->m_vdencIpdlRowstoreCache.enabled   = true;
-            this->m_vdencIpdlRowstoreCache.dwAddress = address;
+            constexpr bool enable[16][5] =
+            {
+                { 1, 1, 1, 0, 1 }, { 1, 1, 1, 1, 1 }, { 1, 1, 0, 0, 0 }, { 1, 1, 0, 1, 0 },
+                { 1, 1, 1, 1, 1 }, { 1, 1, 0, 0, 1 }, { 1, 1, 1, 0, 0 }, { 1, 0, 1, 0, 1 },
+                { 1, 1, 1, 0, 0 }, { 1, 0, 1, 0, 1 }, { 1, 1, 1, 1, 1 }, { 1, 1, 0, 1, 1 },
+                { 1, 1, 1, 1, 1 }, { 1, 0, 1, 1, 1 }, { 1, 1, 1, 1, 1 }, { 1, 0, 1, 1, 1 }
+            };
+    
+            constexpr uint32_t address[16][5] =
+            {
+                { 0, 256, 1280,    0, 2048 }, { 0, 256, 1280, 1824, 1792 }, { 0, 512,    0,    0,    0 }, { 0, 256,   0, 2304,    0 },
+                { 0, 256, 1024,    0, 1792 }, { 0, 512,    0,    0, 2048 }, { 0, 256, 1792,    0,    0 }, { 0,   0, 512,    0, 2048 },
+                { 0, 256, 1792,    0,    0 }, { 0,   0,  256,    0, 1792 }, { 0, 256, 1024, 1568, 1536 }, { 0, 512,   0, 2112, 2048 },
+                { 0, 256, 1792, 2336, 2304 }, { 0,   0,  512, 1600, 1536 }, { 0, 128, 1664, 2336, 2304 }, { 0,   0, 256, 1600, 1536 }
+            };
+
+            bool     isLcu32or64 = par.lcuSize == RowStorePar::SIZE_32 || par.lcuSize == RowStorePar::SIZE_64;
+            bool     isGt4k      = par.frameWidth > 4096;
+            bool     isGt8k      = par.frameWidth > 8192;
+            uint32_t index       = 0;
+
+            if (par.format != RowStorePar::YUV444)
+            {
+                index = 2 * isGt4k + isLcu32or64;
+            }
+            else
+            {
+                uint32_t subidx = par.bitDepth == RowStorePar::DEPTH_12 ? 2 : (par.bitDepth == RowStorePar::DEPTH_10 ? 1 : 0);
+                index           = 4 + 6 * isLcu32or64 + 2 * subidx + isGt4k;
+            }
+
+            if (!isGt8k && this->m_rowStoreCache.vdenc.supported)
+            {
+                this->m_rowStoreCache.vdenc.enabled   = enable[index][3];
+                if (this->m_rowStoreCache.vdenc.enabled)
+                {
+                    this->m_rowStoreCache.vdenc.dwAddress = address[index][3];
+                }
+            }
+
+            break;
+        }
+        case RowStorePar::AV1:
+        {
+            if (this->m_rowStoreCache.vdenc.supported)
+            {
+                this->m_rowStoreCache.vdenc.enabled   = true;
+                this->m_rowStoreCache.vdenc.dwAddress = 2370;
+            }
+            if (this->m_rowStoreCache.ipdl.supported)
+            {
+                this->m_rowStoreCache.ipdl.enabled   = true;
+                this->m_rowStoreCache.ipdl.dwAddress = 384;
+            }
+
+            break;
+        }
+        default:
+        {
+            break;
+        }
         }
 
         return MOS_STATUS_SUCCESS;
@@ -180,8 +243,11 @@ public:
 protected:
     using base_t = Itf;
 
-    vdbox::RowStoreCache             m_vdencRowStoreCache                                       = {};
-    vdbox::RowStoreCache             m_vdencIpdlRowstoreCache                                   = {};
+    struct
+    {
+        RowStoreCache vdenc;
+        RowStoreCache ipdl;
+    } m_rowStoreCache                                                                           = {};
     MHW_MEMORY_OBJECT_CONTROL_PARAMS m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_END_CODEC] = {};
 
     Impl(PMOS_INTERFACE osItf) : mhw::Impl(osItf)
@@ -234,7 +300,7 @@ protected:
             &userFeatureData,
             m_osItf->pOsContext);
 #endif  // _DEBUG || _RELEASE_INTERNAL
-        this->m_vdencRowStoreCache.supported = userFeatureData.i32Data ? false : true;
+        this->m_rowStoreCache.vdenc.supported = userFeatureData.i32Data ? false : true;
 
         MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
 #if (_DEBUG || _RELEASE_INTERNAL)
@@ -244,7 +310,7 @@ protected:
             &userFeatureData,
             m_osItf->pOsContext);
 #endif  // _DEBUG || _RELEASE_INTERNAL
-        this->m_vdencIpdlRowstoreCache.supported = userFeatureData.i32Data ? false : true;
+        this->m_rowStoreCache.ipdl.supported = userFeatureData.i32Data ? false : true;
 
         return MOS_STATUS_SUCCESS;
     }
@@ -381,8 +447,6 @@ protected:
         {
             cmd.OriginalUncompressedPicture.PictureFields.DW0.MemoryCompressionEnable = MmcEnabled(params.mmcStateRaw);
             cmd.OriginalUncompressedPicture.PictureFields.DW0.CompressionType         = MmcRcEnabled(params.mmcStateRaw);
-            cmd.OriginalUncompressedPicture.PictureFields.DW0.MemoryObjectControlState =
-                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_ORIGINAL_UNCOMPRESSED_PICTURE_ENCODE].Value;
             cmd.OriginalUncompressedPicture.PictureFields.DW0.CompressionFormat = params.compressionFormatRaw;
 
             resourceParams                 = {};
@@ -393,22 +457,24 @@ protected:
             resourceParams.bIsWritable     = false;
             resourceParams.HwCommandType   = MOS_VDENC_PIPE_BUF_ADDR;
 
+            InitMocsParams(resourceParams, &cmd.OriginalUncompressedPicture.PictureFields.DW0.Value, 1, 6);
+
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.OriginalUncompressedPicture.PictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_ORIGINAL_UNCOMPRESSED_PICTURE_ENCODE].Gen12_7.Index;
         }
 
-        if (this->m_vdencRowStoreCache.enabled)
+        if (this->m_rowStoreCache.vdenc.enabled)
         {
             cmd.RowStoreScratchBuffer.BufferPictureFields.DW0.CacheSelect = cmd_t::VDENC_Surface_Control_Bits_CMD::CACHE_SELECT_UNNAMED1;
-            cmd.RowStoreScratchBuffer.LowerAddress.DW0.Value              = this->m_vdencRowStoreCache.dwAddress << 6;
+            cmd.RowStoreScratchBuffer.LowerAddress.DW0.Value              = this->m_rowStoreCache.vdenc.dwAddress << 6;
         }
         else if (!Mos_ResourceIsNull(params.intraRowStoreScratchBuffer))
         {
-            cmd.RowStoreScratchBuffer.BufferPictureFields.DW0.MemoryObjectControlState =
-                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_VDENC_ROW_STORE_BUFFER_CODEC].Value;
-
             resourceParams.presResource    = params.intraRowStoreScratchBuffer;
             resourceParams.dwOffset        = 0;
             resourceParams.pdwCmd          = (uint32_t *)&(cmd.RowStoreScratchBuffer.LowerAddress);
@@ -416,17 +482,19 @@ protected:
             resourceParams.bIsWritable     = true;
             resourceParams.HwCommandType   = MOS_VDENC_PIPE_BUF_ADDR;
 
+            InitMocsParams(resourceParams, &cmd.RowStoreScratchBuffer.BufferPictureFields.DW0.Value, 1, 6);
+
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.RowStoreScratchBuffer.BufferPictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_VDENC_ROW_STORE_BUFFER_CODEC].Gen12_7.Index;
         }
 
         if (!Mos_ResourceIsNull(params.streamOutBuffer))
         {
-            cmd.VdencStatisticsStreamout.PictureFields.DW0.MemoryObjectControlState =
-                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_STREAMOUT_DATA_CODEC].Value;
-
             resourceParams.presResource    = params.streamOutBuffer;
             resourceParams.dwOffset        = params.streamOutOffset;
             resourceParams.pdwCmd          = (uint32_t *)&(cmd.VdencStatisticsStreamout.LowerAddress);
@@ -434,28 +502,35 @@ protected:
             resourceParams.bIsWritable     = true;
             resourceParams.HwCommandType   = MOS_VDENC_PIPE_BUF_ADDR;
 
+            InitMocsParams(resourceParams, &cmd.VdencStatisticsStreamout.PictureFields.DW0.Value, 1, 6);
+
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.VdencStatisticsStreamout.PictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_STREAMOUT_DATA_CODEC].Gen12_7.Index;
         }
 
         if (!Mos_ResourceIsNull(params.streamInBuffer))
         {
-            cmd.StreaminDataPicture.PictureFields.DW0.MemoryObjectControlState =
-                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_VDENC_STREAMIN_CODEC].Value;
-
             resourceParams.presResource    = params.streamInBuffer;
-            resourceParams.dwOffset        = 0;
+            resourceParams.dwOffset        = params.streamInBuffer->dwResourceOffset;
             resourceParams.pdwCmd          = (uint32_t *)&(cmd.StreaminDataPicture.LowerAddress);
             resourceParams.dwLocationInCmd = _MHW_CMD_DW_LOCATION(StreaminDataPicture.LowerAddress);
             resourceParams.bIsWritable     = false;
             resourceParams.HwCommandType   = MOS_VDENC_PIPE_BUF_ADDR;
 
+            InitMocsParams(resourceParams, &cmd.StreaminDataPicture.PictureFields.DW0.Value, 1, 6);
+
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.StreaminDataPicture.PictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_VDENC_STREAMIN_CODEC].Gen12_7.Index;
         }
 
         typename cmd_t::VDENC_Reference_Picture_CMD *fwdRefs[] =
@@ -489,18 +564,23 @@ protected:
                 resourceParams.pdwCmd          = (uint32_t *)&fwdRefs[refIdx]->LowerAddress;
                 resourceParams.HwCommandType   = MOS_VDENC_PIPE_BUF_ADDR;
 
+                uint8_t mmcSkip = (params.mmcSkipMask) & (1 << refIdx);
+
                 auto mmcMode = (params.mmcStatePostDeblock != MOS_MEMCOMP_DISABLED) ? params.mmcStatePostDeblock : params.mmcStatePreDeblock;
 
-                fwdRefs[refIdx]->PictureFields.DW0.MemoryCompressionEnable = MmcEnabled(mmcMode);
-                fwdRefs[refIdx]->PictureFields.DW0.CompressionType         = MmcRcEnabled(mmcMode);
-                fwdRefs[refIdx]->PictureFields.DW0.MemoryObjectControlState =
-                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+                fwdRefs[refIdx]->PictureFields.DW0.MemoryCompressionEnable = mmcSkip ? 0 : MmcEnabled(mmcMode);
+                fwdRefs[refIdx]->PictureFields.DW0.CompressionType         = mmcSkip ? MOS_MEMCOMP_DISABLED : MmcRcEnabled(mmcMode);
                 fwdRefs[refIdx]->PictureFields.DW0.CompressionFormat = params.compressionFormatRecon;
 
+                InitMocsParams(resourceParams, &fwdRefs[refIdx]->PictureFields.DW0.Value, 1, 6);
+
                 MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                     this->m_osItf,
                     this->m_currentCmdBuf,
                     &resourceParams));
+
+                fwdRefs[refIdx]->PictureFields.DW0.MemoryObjectControlState =
+                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
             }
 
             if (!Mos_ResourceIsNull(params.refsDsStage1[refIdx]) && refIdx < sizeof(fwdRefsDsStage1) / sizeof(fwdRefsDsStage1[0]))
@@ -520,13 +600,16 @@ protected:
 
                 fwdRefsDsStage1[refIdx]->PictureFields.DW0.MemoryCompressionEnable = MmcEnabled(mmcMode);
                 fwdRefsDsStage1[refIdx]->PictureFields.DW0.CompressionType         = MmcRcEnabled(mmcMode);
-                fwdRefsDsStage1[refIdx]->PictureFields.DW0.MemoryObjectControlState =
-                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+
+                InitMocsParams(resourceParams, &fwdRefsDsStage1[refIdx]->PictureFields.DW0.Value, 1, 6);
 
                 MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                     this->m_osItf,
                     this->m_currentCmdBuf,
                     &resourceParams));
+
+                fwdRefsDsStage1[refIdx]->PictureFields.DW0.MemoryObjectControlState =
+                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
             }
 
             if (!Mos_ResourceIsNull(params.refsDsStage2[refIdx]) && refIdx < sizeof(fwdRefsDsStage2) / sizeof(fwdRefsDsStage2[0]))
@@ -546,14 +629,17 @@ protected:
 
                 fwdRefsDsStage2[refIdx]->PictureFields.DW0.MemoryCompressionEnable = MmcEnabled(mmcMode);
                 fwdRefsDsStage2[refIdx]->PictureFields.DW0.CompressionType         = MmcRcEnabled(mmcMode);
-                fwdRefsDsStage2[refIdx]->PictureFields.DW0.MemoryObjectControlState =
-                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+
+                InitMocsParams(resourceParams, &fwdRefsDsStage2[refIdx]->PictureFields.DW0.Value, 1, 6);
 
                 MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                     this->m_osItf,
                     this->m_currentCmdBuf,
                     &resourceParams));
 
+                fwdRefsDsStage2[refIdx]->PictureFields.DW0.MemoryObjectControlState =
+                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
+
                 if (params.numActiveRefL0 == 2 && params.numActiveRefL1 == 1 && refIdx == 1)
                 {
                     resourceParams.dwLocationInCmd = fwdRefsDsStage2DwLoaction[refIdx + 1];
@@ -562,13 +648,16 @@ protected:
 
                     fwdRefsDsStage2[refIdx + 1]->PictureFields.DW0.MemoryCompressionEnable = MmcEnabled(mmcMode);
                     fwdRefsDsStage2[refIdx + 1]->PictureFields.DW0.CompressionType         = MmcRcEnabled(mmcMode);
-                    fwdRefsDsStage2[refIdx + 1]->PictureFields.DW0.MemoryObjectControlState =
-                        this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+
+                    InitMocsParams(resourceParams, &fwdRefsDsStage2[refIdx + 1]->PictureFields.DW0.Value, 1, 6);
 
                     MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                         this->m_osItf,
                         this->m_currentCmdBuf,
                         &resourceParams));
+
+                    fwdRefsDsStage2[refIdx + 1]->PictureFields.DW0.MemoryObjectControlState =
+                        this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
                 }
             }
         }
@@ -592,14 +681,17 @@ protected:
 
                 cmd.BwdRef0.PictureFields.DW0.MemoryCompressionEnable = MmcEnabled(mmcMode);
                 cmd.BwdRef0.PictureFields.DW0.CompressionType         = MmcRcEnabled(mmcMode);
-                cmd.BwdRef0.PictureFields.DW0.MemoryObjectControlState =
-                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
                 cmd.BwdRef0.PictureFields.DW0.CompressionFormat = params.compressionFormatRecon;
 
+                InitMocsParams(resourceParams, &cmd.BwdRef0.PictureFields.DW0.Value, 1, 6);
+
                 MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                     this->m_osItf,
                     this->m_currentCmdBuf,
                     &resourceParams));
+
+                cmd.BwdRef0.PictureFields.DW0.MemoryObjectControlState =
+                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
             }
 
             if (!Mos_ResourceIsNull(params.refsDsStage1[refIdx]))
@@ -619,13 +711,16 @@ protected:
 
                 cmd.DsBwdRef0.PictureFields.DW0.MemoryCompressionEnable = MmcEnabled(mmcMode);
                 cmd.DsBwdRef0.PictureFields.DW0.CompressionType         = MmcRcEnabled(mmcMode);
-                cmd.DsBwdRef0.PictureFields.DW0.MemoryObjectControlState =
-                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+
+                InitMocsParams(resourceParams, &cmd.DsBwdRef0.PictureFields.DW0.Value, 1, 6);
 
                 MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                     this->m_osItf,
                     this->m_currentCmdBuf,
                     &resourceParams));
+
+                cmd.DsBwdRef0.PictureFields.DW0.MemoryObjectControlState =
+                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
             }
 
             if (!Mos_ResourceIsNull(params.refsDsStage2[refIdx]))
@@ -645,13 +740,16 @@ protected:
 
                 cmd.DsBwdRef04X.PictureFields.DW0.MemoryCompressionEnable = MmcEnabled(mmcMode);
                 cmd.DsBwdRef04X.PictureFields.DW0.CompressionType         = MmcRcEnabled(mmcMode);
-                cmd.DsBwdRef04X.PictureFields.DW0.MemoryObjectControlState =
-                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+
+                InitMocsParams(resourceParams, &cmd.DsBwdRef04X.PictureFields.DW0.Value, 1, 6);
 
                 MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                     this->m_osItf,
                     this->m_currentCmdBuf,
                     &resourceParams));
+
+                cmd.DsBwdRef04X.PictureFields.DW0.MemoryObjectControlState =
+                    this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
             }
         }
 
@@ -666,13 +764,16 @@ protected:
 
             cmd.ColocatedMv.PictureFields.DW0.MemoryCompressionEnable = 0;
             cmd.ColocatedMv.PictureFields.DW0.CompressionType         = 0;
-            cmd.ColocatedMv.PictureFields.DW0.MemoryObjectControlState =
-                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+
+            InitMocsParams(resourceParams, &cmd.ColocatedMv.PictureFields.DW0.Value, 1, 6);
 
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.ColocatedMv.PictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
         }
 
         if (!Mos_ResourceIsNull(params.colMvTempBuffer[0]))
@@ -686,13 +787,16 @@ protected:
 
             cmd.ColocatedMv.PictureFields.DW0.MemoryCompressionEnable = 0;
             cmd.ColocatedMv.PictureFields.DW0.CompressionType         = 0;
-            cmd.ColocatedMv.PictureFields.DW0.MemoryObjectControlState =
-                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+
+            InitMocsParams(resourceParams, &cmd.ColocatedMv.PictureFields.DW0.Value, 1, 6);
 
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.ColocatedMv.PictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
         }
 
         if (params.surfaceDsStage1)
@@ -708,13 +812,16 @@ protected:
 
             cmd.ScaledReferenceSurfaceStage1.PictureFields.DW0.MemoryCompressionEnable = MmcEnabled(mmcMode);
             cmd.ScaledReferenceSurfaceStage1.PictureFields.DW0.CompressionType         = MmcRcEnabled(mmcMode);
-            cmd.ScaledReferenceSurfaceStage1.PictureFields.DW0.MemoryObjectControlState =
-                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+
+            InitMocsParams(resourceParams, &cmd.ScaledReferenceSurfaceStage1.PictureFields.DW0.Value, 1, 6);
 
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.ScaledReferenceSurfaceStage1.PictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
         }
 
         if (params.surfaceDsStage2)
@@ -730,13 +837,16 @@ protected:
 
             cmd.ScaledReferenceSurfaceStage2.PictureFields.DW0.MemoryCompressionEnable = MmcEnabled(mmcMode);
             cmd.ScaledReferenceSurfaceStage2.PictureFields.DW0.CompressionType         = MmcRcEnabled(mmcMode);
-            cmd.ScaledReferenceSurfaceStage2.PictureFields.DW0.MemoryObjectControlState =
-                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+
+            InitMocsParams(resourceParams, &cmd.ScaledReferenceSurfaceStage2.PictureFields.DW0.Value, 1, 6);
 
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.ScaledReferenceSurfaceStage2.PictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
         }
 
         if (!Mos_ResourceIsNull(params.pakObjCmdStreamOutBuffer))
@@ -750,13 +860,16 @@ protected:
 
             cmd.VdencLcuPakObjCmdBuffer.PictureFields.DW0.MemoryCompressionEnable = 0;
             cmd.VdencLcuPakObjCmdBuffer.PictureFields.DW0.CompressionType         = 0;
-            cmd.VdencLcuPakObjCmdBuffer.PictureFields.DW0.MemoryObjectControlState =
-                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+
+            InitMocsParams(resourceParams, &cmd.VdencLcuPakObjCmdBuffer.PictureFields.DW0.Value, 1, 6);
 
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.VdencLcuPakObjCmdBuffer.PictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
         }
 
         if (!Mos_ResourceIsNull(params.segmentMapStreamInBuffer))
@@ -768,10 +881,15 @@ protected:
             resourceParams.bIsWritable     = true;
             resourceParams.HwCommandType   = MOS_VDENC_PIPE_BUF_ADDR;
 
+            InitMocsParams(resourceParams, &cmd.Vp9SegmentationMapStreaminBuffer.PictureFields.DW0.Value, 1, 6);
+
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.Vp9SegmentationMapStreaminBuffer.PictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
         }
 
         if (!Mos_ResourceIsNull(params.segmentMapStreamOutBuffer))
@@ -783,10 +901,15 @@ protected:
             resourceParams.bIsWritable     = true;
             resourceParams.HwCommandType   = MOS_VDENC_PIPE_BUF_ADDR;
 
+            InitMocsParams(resourceParams, &cmd.Vp9SegmentationMapStreamoutBuffer.PictureFields.DW0.Value, 1, 6);
+
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.Vp9SegmentationMapStreamoutBuffer.PictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_STREAMOUT_DATA_CODEC].Gen12_7.Index;
         }
 
         cmd.DW61.WeightsHistogramStreamoutOffset = 3 * MHW_CACHELINE_SIZE;
@@ -800,19 +923,21 @@ protected:
             resourceParams.bIsWritable     = true;
             resourceParams.HwCommandType   = MOS_VDENC_PIPE_BUF_ADDR;
 
-            cmd.VdencTileRowStoreBuffer.BufferPictureFields.DW0.MemoryObjectControlState =
-                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_VDENC_ROW_STORE_BUFFER_CODEC].Value;
+            InitMocsParams(resourceParams, &cmd.VdencTileRowStoreBuffer.BufferPictureFields.DW0.Value, 1, 6);
 
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.VdencTileRowStoreBuffer.BufferPictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_VDENC_ROW_STORE_BUFFER_CODEC].Gen12_7.Index;
         }
 
-        if (this->m_vdencIpdlRowstoreCache.enabled)
+        if (this->m_rowStoreCache.ipdl.enabled)
         {
             cmd.IntraPredictionRowstoreBaseAddress.BufferPictureFields.DW0.CacheSelect = cmd_t::VDENC_Surface_Control_Bits_CMD::CACHE_SELECT_UNNAMED1;
-            cmd.IntraPredictionRowstoreBaseAddress.LowerAddress.DW0.Value              = m_vdencIpdlRowstoreCache.dwAddress << 6;
+            cmd.IntraPredictionRowstoreBaseAddress.LowerAddress.DW0.Value              = this->m_rowStoreCache.ipdl.dwAddress << 6;
         }
         else if (!Mos_ResourceIsNull(params.mfdIntraRowStoreScratchBuffer))
         {
@@ -823,14 +948,17 @@ protected:
             resourceParams.bIsWritable     = true;
             resourceParams.HwCommandType   = MOS_VDENC_PIPE_BUF_ADDR;
 
-            cmd.IntraPredictionRowstoreBaseAddress.BufferPictureFields.DW0.MemoryObjectControlState =
-                m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_INTRA_ROWSTORE_SCRATCH_BUFFER_CODEC].Value;
             cmd.IntraPredictionRowstoreBaseAddress.BufferPictureFields.DW0.MemoryCompressionEnable = 0;
 
+            InitMocsParams(resourceParams, &cmd.IntraPredictionRowstoreBaseAddress.BufferPictureFields.DW0.Value, 1, 6);
+
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.IntraPredictionRowstoreBaseAddress.BufferPictureFields.DW0.MemoryObjectControlState =
+                m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_INTRA_ROWSTORE_SCRATCH_BUFFER_CODEC].Gen12_7.Index;
         }
 
         if (!Mos_ResourceIsNull(params.cumulativeCuCountStreamOutBuffer))
@@ -842,6 +970,8 @@ protected:
             resourceParams.bIsWritable     = true;
             resourceParams.HwCommandType   = MOS_VDENC_PIPE_BUF_ADDR;
 
+            InitMocsParams(resourceParams, &cmd.VdencCumulativeCuCountStreamoutSurface.PictureFields.DW0.Value, 1, 6);
+
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
@@ -859,13 +989,16 @@ protected:
 
             cmd.ColocatedMvAvcWriteBuffer.PictureFields.DW0.MemoryCompressionEnable = 0;
             cmd.ColocatedMvAvcWriteBuffer.PictureFields.DW0.CompressionType         = 0;
-            cmd.ColocatedMvAvcWriteBuffer.PictureFields.DW0.MemoryObjectControlState =
-                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Value;
+
+            InitMocsParams(resourceParams, &cmd.ColocatedMvAvcWriteBuffer.PictureFields.DW0.Value, 1, 6);
 
             MHW_CHK_STATUS_RETURN(this->AddResourceToCmd(
                 this->m_osItf,
                 this->m_currentCmdBuf,
                 &resourceParams));
+
+            cmd.ColocatedMvAvcWriteBuffer.PictureFields.DW0.MemoryObjectControlState =
+                this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_REFERENCE_PICTURE_CODEC].Gen12_7.Index;
         }
 
         return MOS_STATUS_SUCCESS;
@@ -939,7 +1072,7 @@ protected:
     DO_FIELD(DW9, LcuStreamOutOffsetEnable, params.tileEnable);                                                           \
     DO_FIELD(DW9, TileLcuStreamOutOffset, params.tileLCUStreamOutOffset);                                                 \
                                                                                                                           \
-    DO_FIELD(DW17, CumulativeCuTileOffsetEnable, params.tileEnable);                                                      \
+    DO_FIELD(DW17, CumulativeCuTileOffsetEnable, params.cumulativeCUTileOffsetEn);                                        \
     DO_FIELD(DW17, CumulativeCuTileOffset, params.cumulativeCUTileOffset);                                                \
     __MHW_VDBOX_VDENC_WRAPPER_EXT(VDENC_HEVC_VP9_TILE_SLICE_STATE_IMPL_EXT)
 
