@@ -35,6 +35,7 @@
 namespace vp
 {
 class VpPlatformInterface;
+class VpUserFeatureControl;
 }
 
 using VP_PIPELINE_PARAMS   = VPHAL_RENDER_PARAMS;
@@ -51,12 +52,29 @@ using PCVP_PIPELINE_PARAMS = const VPHAL_RENDER_PARAMS*;
 #define VP_VEBOX_FLAG_ENABLE_KERNEL_FMD_SUMMATION          0x00000010
 
 #define RESOURCE_ASSIGNMENT_HINT_BITS_DI        \
-    uint32_t    bDi         : 1;                \
-    uint32_t    b60fpsDi    : 1;                \
+    uint32_t    bDi                 : 1;        \
+    uint32_t    b60fpsDi            : 1;
+
+#define RESOURCE_ASSIGNMENT_HINT_BITS_SCALING   \
+    uint32_t    isIScalingTypeNone  : 1;        \
+    uint32_t    isFieldWeaving      : 1;
 
 #define RESOURCE_ASSIGNMENT_HINT_BITS           \
-        RESOURCE_ASSIGNMENT_HINT_BITS_DI
-#define RESOURCE_ASSIGNMENT_HINT_SIZE   2
+        RESOURCE_ASSIGNMENT_HINT_BITS_DI        \
+        RESOURCE_ASSIGNMENT_HINT_BITS_SCALING
+
+#define RESOURCE_ASSIGNMENT_HINT_SIZE   4
+
+//!
+//! \brief Enumeration for the user feature key "Bypass Composition" values
+//!
+typedef enum _VPHAL_COMP_BYPASS_MODE
+{
+    VPHAL_COMP_BYPASS_NOT_SET  = 0xffffffff,
+    VPHAL_COMP_BYPASS_DISABLED = 0x0,
+    VPHAL_COMP_BYPASS_ENABLED  = 0x1,
+    VPHAL_COMP_BYPASS_DEFAULT  = 0x2
+} VPHAL_COMP_BYPASS_MODE, *PVPHAL_COMP_BYPASS_MODE;
 
 struct VP_SURFACE
 {
@@ -114,6 +132,9 @@ struct _VP_EXECUTE_CAPS
             uint64_t bSecureVebox   : 1;   // Vebox in Secure Mode
 
             uint64_t bOutputPipeFeatureInuse : 1; // Output surface of pipeline is in use.
+            uint64_t bForceCscToRender : 1; // If true, force to use render for csc.
+            uint64_t bForceProcampToRender : 1;   // If true, force to use render for procamp.
+            uint64_t lastSubmission : 1;    // If true, it's the last submission of current DDI.
 
             // Vebox Features
             uint64_t bDN            : 1;   // Vebox DN needed
@@ -137,6 +158,8 @@ struct _VP_EXECUTE_CAPS
             uint64_t bHDR3DLUT      : 1;  // Vebox 3DLUT needed
             uint64_t bDV            : 1;
             uint64_t b3DlutOutput   : 1;
+            uint64_t bCappipe       : 1;
+            uint64_t bLgca          : 1;
 
             // SFC features
             uint64_t bSfcCsc        : 1;   // Sfc Csc enabled
@@ -183,6 +206,9 @@ typedef struct _VP_EngineEntry
             uint32_t sfc2PassScalingNeededX : 1;
             uint32_t sfc2PassScalingNeededY : 1;
             uint32_t usedForNextPass : 1;       // true if current feature should be bypassed for current pass and be processed during next pass.
+            uint32_t sfcNotSupported : 1;       // true if sfc cannot be selected.
+            uint32_t veboxNotSupported : 1;     // true if vebox cannot be selected.
+            uint32_t onlyParamCalculation : 1;  // true if the feature is used for parameter calculation.
         };
         uint32_t value;
     };
