@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2020, Intel Corporation
+* Copyright (c) 2019-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -47,7 +47,8 @@
 #include <unistd.h>  // fork
 #include <algorithm>
 
-const char *MosUtilitiesSpecificNext::m_szUserFeatureFile = USER_FEATURE_FILE;
+const char           *MosUtilitiesSpecificNext::m_szUserFeatureFile     = USER_FEATURE_FILE;
+MOS_PUF_KEYLIST      MosUtilitiesSpecificNext::m_ufKeyList              = nullptr;
 
 double MosUtilities::MosGetTime()
 {
@@ -57,7 +58,7 @@ double MosUtilities::MosGetTime()
 }
 
 //!
-//! \brief Linux specific user feature define, used in MOS_UserFeature_ParsePath
+//! \brief Linux specific user feature define, used in MosUtilities::MosUserFeatureParsePath
 //!        They can be unified with the win definitions, since they are identical.
 //!
 #define MOS_UF_SEPARATOR  "\\"
@@ -69,6 +70,7 @@ double MosUtilities::MosGetTime()
 //!
 const char *const MosUtilitiesSpecificNext::m_mosTracePath  = "/sys/kernel/debug/tracing/trace_marker_raw";
 int32_t           MosUtilitiesSpecificNext::m_mosTraceFd    = -1;
+MosMutex          MosUtilitiesSpecificNext::m_userSettingMutex;
 
 std::map<std::string, std::map<std::string, std::string>> MosUtilitiesSpecificNext::m_regBuffer;
 
@@ -540,7 +542,7 @@ void MosUtilities::MosSleep(uint32_t mSec)
 
     iResult = -1;
 
-    for ( i = 0; i < (int32_t)UFKey.ulValueNum; i++ )
+    for ( i = 0; i < UFKey.valueNum; i++ )
     {
         iResult = strcmp(UFKey.pValueArray[i].pcValueName, pcValueName);
         if ( iResult == 0 )
@@ -566,7 +568,7 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureAdd(MOS_PUF_KEYLIST *pKeyList, M
         return MOS_STATUS_INVALID_PARAMETER;
     }
 
-    pNewNode = (MOS_UF_KEYNODE*)MOS_AllocMemory(sizeof(MOS_UF_KEYNODE));
+    pNewNode = (MOS_UF_KEYNODE *)MOS_AllocAndZeroMemory(sizeof(MOS_UF_KEYNODE));
     if (pNewNode == nullptr)
     {
         return MOS_STATUS_NO_SPACE;
@@ -604,41 +606,38 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureSet(MOS_PUF_KEYLIST *pKeyList, M
     }
 
     // Prepare the ValueBuff of the NewKey
-    if ((ulValueBuf = MOS_AllocMemory(NewKey.pValueArray[0].ulValueLen)) == nullptr)
+    if ((ulValueBuf = MOS_AllocAndZeroMemory(NewKey.pValueArray[0].ulValueLen)) == nullptr)
     {
          return MOS_STATUS_NO_SPACE;
     }
+    MosUtilities::MosAtomicIncrement(&MosUtilities::m_mosMemAllocFakeCounter);  //ulValueBuf does not count it, because it is freed after the MEMNJA final report.
+    MOS_OS_NORMALMESSAGE("ulValueBuf %p for key %s", ulValueBuf, NewKey.pValueArray[0].pcValueName);
 
-    if ( (iPos = UserFeatureFindValue(*Key, NewKey.pValueArray[0].pcValueName)) == NOT_FOUND)
+    m_userSettingMutex.Lock();
+    if ((iPos = UserFeatureFindValue(*Key, NewKey.pValueArray[0].pcValueName)) == NOT_FOUND)
     {
         //not found, add a new value to key struct.
         //reallocate memory for appending this value.
-        pValueArray = (MOS_UF_VALUE*)MOS_AllocMemory(sizeof(MOS_UF_VALUE)*(Key->ulValueNum+1));
-        if (pValueArray == nullptr)
+        iPos = MosUtilities::MosAtomicIncrement(&Key->valueNum);
+        iPos = iPos - 1;
+        if (iPos >= UF_CAPABILITY)
         {
-            MOS_FreeMemory(ulValueBuf);
-            return MOS_STATUS_NO_SPACE;
+            MOS_OS_ASSERTMESSAGE("user setting requires iPos (%d) < UF_CAPABILITY(64)", iPos);
+            Key->valueNum = UF_CAPABILITY;
+            MOS_SafeFreeMemory(ulValueBuf);
+            m_userSettingMutex.Unlock();
+            return MOS_STATUS_USER_FEATURE_KEY_READ_FAILED;
         }
-
-        MosUtilities::MosSecureMemcpy(pValueArray,
-                        sizeof(MOS_UF_VALUE)*(Key->ulValueNum),
-                        Key->pValueArray,
-                        sizeof(MOS_UF_VALUE)*(Key->ulValueNum));
-
-        MOS_FreeMemory(Key->pValueArray);
-
-        Key->pValueArray = pValueArray;
-
-        iPos = Key->ulValueNum;
-        MosUtilities::MosSecureStrcpy(Key->pValueArray[Key->ulValueNum].pcValueName,
+        MosUtilities::MosSecureStrcpy(Key->pValueArray[iPos].pcValueName,
             MAX_USERFEATURE_LINE_LENGTH,
             NewKey.pValueArray[0].pcValueName);
-        Key->ulValueNum ++;
     }
     else
     {
         //if found, the previous value buffer needs to be freed before reallocating
         MOS_FreeMemory(Key->pValueArray[iPos].ulValueBuf);
+        MosUtilities::MosAtomicDecrement(&MosUtilities::m_mosMemAllocFakeCounter);
+        MOS_OS_NORMALMESSAGE("ulValueBuf %p for key %s", ulValueBuf, NewKey.pValueArray[0].pcValueName);
     }
 
     Key->pValueArray[iPos].ulValueLen  = NewKey.pValueArray[0].ulValueLen;
@@ -652,6 +651,7 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureSet(MOS_PUF_KEYLIST *pKeyList, M
                      NewKey.pValueArray[0].ulValueBuf,
                      NewKey.pValueArray[0].ulValueLen);
 
+    m_userSettingMutex.Unlock();
     return MOS_STATUS_SUCCESS;
 }
 
@@ -733,14 +733,14 @@ MOS_STATUS  MosUtilitiesSpecificNext::UserFeatureDumpFile(const char * const szF
     iCurId    =  0;
     eStatus  =  MOS_STATUS_SUCCESS;
 
-    CurKey = (MOS_UF_KEY*)MOS_AllocMemory(sizeof(MOS_UF_KEY));
+    CurKey = (MOS_UF_KEY *)MOS_AllocAndZeroMemory(sizeof(MOS_UF_KEY));
     if (CurKey == nullptr)
     {
         return MOS_STATUS_NO_SPACE;
     }
-    CurKey->ulValueNum       = 0;
+    CurKey->valueNum        = 0;
     CurKey->pcKeyName[0]    = '\0';
-    CurKey->pValueArray       = nullptr;
+    CurKey->pValueArray     = nullptr;
 
     if ( (File = fopen(szFileName, "r")) == nullptr)
     {
@@ -765,13 +765,13 @@ MOS_STATUS  MosUtilitiesSpecificNext::UserFeatureDumpFile(const char * const szF
                 // Add last key struct to contents when the key is not first.
                 // otherwise, continue to load key struct data.
                 CurKey->pValueArray   = CurValue;
-                CurKey->ulValueNum   = iCount;
+                CurKey->valueNum      = iCount;
                 if(UserFeatureAdd(pKeyList, CurKey) != MOS_STATUS_SUCCESS)
                 {
                     // if the CurKey didn't be added in pKeyList, free it.
                     MOS_FreeMemory(CurKey);
                 }
-                CurKey = (MOS_UF_KEY*)MOS_AllocMemory(sizeof(MOS_UF_KEY));
+                CurKey = (MOS_UF_KEY *)MOS_AllocAndZeroMemory(sizeof(MOS_UF_KEY));
                 if (CurKey == nullptr)
                 {
                     eStatus = MOS_STATUS_NO_SPACE;
@@ -793,10 +793,10 @@ MOS_STATUS  MosUtilitiesSpecificNext::UserFeatureDumpFile(const char * const szF
             }
 
             MosUtilities::MosSecureStrcpy(CurKey->pcKeyName, MAX_USERFEATURE_LINE_LENGTH, szTmp);
-            CurKey->ulValueNum = 0;
+            CurKey->valueNum = 0;
 
             // allocate capability length for valuearray.
-            CurValue = (MOS_UF_VALUE*)MOS_AllocMemory(sizeof(MOS_UF_VALUE)*UF_CAPABILITY);
+            CurValue = (MOS_UF_VALUE *)MOS_AllocAndZeroMemory(sizeof(MOS_UF_VALUE) * UF_CAPABILITY);
             if (CurValue == nullptr)
             {
                 eStatus = MOS_STATUS_NO_SPACE;
@@ -826,6 +826,7 @@ MOS_STATUS  MosUtilitiesSpecificNext::UserFeatureDumpFile(const char * const szF
                 if (iCount < 0 || iCount >= UF_CAPABILITY)
                 {
                     eStatus = MOS_STATUS_USER_FEATURE_KEY_READ_FAILED;
+                    MOS_OS_ASSERTMESSAGE("user setting value icount %d, and it must meet  0 < icount < UF_CAPABILITY(64)", iCount);
                     break;
                 }
 
@@ -922,10 +923,10 @@ MOS_STATUS  MosUtilitiesSpecificNext::UserFeatureDumpFile(const char * const szF
     if (eStatus == MOS_STATUS_SUCCESS)
     {
         if ( bEmpty && (strlen(CurKey->pcKeyName) > 0) &&
-            (CurKey->ulValueNum == 0) )
+            (CurKey->valueNum == 0) )
         {
-            CurKey->pValueArray   = CurValue;
-            CurKey->ulValueNum   = iCount;
+            CurKey->pValueArray = CurValue;
+            CurKey->valueNum    = iCount;
             if(UserFeatureAdd(pKeyList, CurKey) != MOS_STATUS_SUCCESS)
             {
                 // if the CurKey didn't be added in pKeyList, free it.
@@ -987,7 +988,7 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureDumpDataToFile(const char *szFil
         fprintf(File, "%s\n", UF_KEY_ID);
         fprintf(File,  "\t0x%.8x\n", (uint32_t)(uintptr_t)pKeyTmp->pElem->UFKey);
         fprintf(File,  "\t%s\n", pKeyTmp->pElem->pcKeyName);
-        for ( j = 0; j < (int32_t)pKeyTmp->pElem->ulValueNum; j ++ )
+        for ( j = 0; j < pKeyTmp->pElem->valueNum; j ++ )
         {
             fprintf(File, "\t\t%s\n", UF_VALUE_ID);
             if ( strlen(pKeyTmp->pElem->pValueArray[j].pcValueName) > 0 )
@@ -1015,10 +1016,9 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureDumpDataToFile(const char *szFil
                     break;
                 } //switch (pKeyTmp->pElem->pValueArray[j].ulValueType)
             }
-        } // for ( j = 0; j < (int32_t)pKeyTmp->pElem->ulValueNum; j ++ )
+        } // for ( j = 0; j < pKeyTmp->pElem->valueNum; j ++ )
     } //for (pKeyTmp = pKeyList; pKeyTmp; pKeyTmp = pKeyTmp->pNext)
     fclose(File);
-    MosUtilities::MosUserFeatureNotifyChangeKeyValue(nullptr, false, nullptr, true);
 
     return MOS_STATUS_SUCCESS;
 }
@@ -1033,7 +1033,7 @@ void MosUtilitiesSpecificNext::UserFeatureFreeKeyList(MOS_PUF_KEYLIST pKeyList)
     while(pKeyTmp)
     {
         pKeyTmpNext = pKeyTmp->pNext;
-        for(i=0;i<pKeyTmp->pElem->ulValueNum;i++)
+        for(i=0;i<pKeyTmp->pElem->valueNum;i++)
         {
             MOS_FreeMemory(pKeyTmp->pElem->pValueArray[i].ulValueBuf);
         }
@@ -1055,12 +1055,10 @@ MOS_STATUS  MosUtilitiesSpecificNext::UserFeatureSetValue(
     MOS_UF_KEY          NewKey;
     MOS_UF_VALUE        NewValue;
     MOS_STATUS          eStatus;
-    MOS_PUF_KEYLIST     pKeyList;
 
     eStatus   = MOS_STATUS_UNKNOWN;
-    pKeyList   = nullptr;
 
-    if ( (strKey== nullptr) || (pcValueName == nullptr) )
+    if ((strKey == nullptr) || (pcValueName == nullptr) || (m_ufKeyList == nullptr))
     {
         return MOS_STATUS_INVALID_PARAMETER;
     }
@@ -1081,20 +1079,13 @@ MOS_STATUS  MosUtilitiesSpecificNext::UserFeatureSetValue(
     MosUtilities::MosZeroMemory(NewKey.pcKeyName, MAX_USERFEATURE_LINE_LENGTH);
     MosUtilities::MosSecureStrcpy(NewKey.pcKeyName, MAX_USERFEATURE_LINE_LENGTH, strKey);
     NewKey.pValueArray = &NewValue;
-    NewKey.ulValueNum = 1;
+    NewKey.valueNum    = 1;
 
-    if ((eStatus = UserFeatureDumpFile(m_szUserFeatureFile, &pKeyList)) != MOS_STATUS_SUCCESS)
+    if ( ( eStatus = UserFeatureSet(&MosUtilitiesSpecificNext::m_ufKeyList, NewKey)) == MOS_STATUS_SUCCESS )
     {
-        UserFeatureFreeKeyList(pKeyList);
-        return eStatus;
+        MosUtilities::MosUserFeatureNotifyChangeKeyValue(nullptr, false, nullptr, true);
     }
 
-    if ( ( eStatus = UserFeatureSet(&pKeyList, NewKey)) == MOS_STATUS_SUCCESS )
-    {
-        eStatus = UserFeatureDumpDataToFile(m_szUserFeatureFile, pKeyList);
-    }
-
-    UserFeatureFreeKeyList(pKeyList);
     return eStatus;
 }
 
@@ -1114,9 +1105,9 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureQueryValue(
     char                strTempValueName[MAX_USERFEATURE_LINE_LENGTH];
 
     eStatus   = MOS_STATUS_UNKNOWN;
-    pKeyList   = nullptr;
+    pKeyList   = MosUtilitiesSpecificNext::m_ufKeyList;
 
-    if ( (strKey == nullptr) || (pcValueName == nullptr))
+    if ( (strKey == nullptr) || (pcValueName == nullptr) || (pKeyList == nullptr))
     {
         return MOS_STATUS_INVALID_PARAMETER;
     }
@@ -1127,23 +1118,19 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureQueryValue(
     MosUtilities::MosZeroMemory(NewKey.pcKeyName, MAX_USERFEATURE_LINE_LENGTH);
     MosUtilities::MosSecureStrcpy(NewKey.pcKeyName, MAX_USERFEATURE_LINE_LENGTH, strKey);
     NewKey.pValueArray = &NewValue;
-    NewKey.ulValueNum = 1;
+    NewKey.valueNum    = 1;
 
-    if ((eStatus = UserFeatureDumpFile(m_szUserFeatureFile, &pKeyList)) == MOS_STATUS_SUCCESS)
+    if ( (eStatus = UserFeatureQuery(pKeyList, &NewKey)) == MOS_STATUS_SUCCESS )
     {
-        if ( (eStatus = UserFeatureQuery(pKeyList, &NewKey)) == MOS_STATUS_SUCCESS )
+        if(uiValueType != nullptr)
         {
-            if(uiValueType != nullptr)
-            {
-                *uiValueType = NewKey.pValueArray[0].ulValueType;
-            }
-            if (nDataSize != nullptr)
-            {
-                *nDataSize   = NewKey.pValueArray[0].ulValueLen;
-            }
+            *uiValueType = NewKey.pValueArray[0].ulValueType;
+        }
+        if (nDataSize != nullptr)
+        {
+            *nDataSize   = NewKey.pValueArray[0].ulValueLen;
         }
     }
-    UserFeatureFreeKeyList(pKeyList);
 
     return eStatus;
 }
@@ -1155,17 +1142,10 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureGetKeyIdbyName(const char  *pcKe
     MOS_STATUS          eStatus;
     MOS_PUF_KEYLIST     pTempNode;
 
-    pKeyList   = nullptr;
+    pKeyList   = MosUtilitiesSpecificNext::m_ufKeyList;
     iResult    = -1;
 
-    if ((eStatus = UserFeatureDumpFile(m_szUserFeatureFile, &pKeyList)) !=
-        MOS_STATUS_SUCCESS )
-    {
-        UserFeatureFreeKeyList(pKeyList);
-        return eStatus;
-    }
-
-    eStatus   = MOS_STATUS_INVALID_PARAMETER;
+    eStatus    = MOS_STATUS_INVALID_PARAMETER;
 
     for(pTempNode=pKeyList; pTempNode; pTempNode=pTempNode->pNext)
     {
@@ -1177,7 +1157,6 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureGetKeyIdbyName(const char  *pcKe
             break;
         }
     }
-    UserFeatureFreeKeyList(pKeyList);
 
     return eStatus;
 }
@@ -1188,7 +1167,7 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureGetKeyNamebyId(void  *UFKey, cha
     MOS_PUF_KEYLIST     pTempNode;
     MOS_STATUS          eStatus;
 
-    pKeyList   = nullptr;
+    pKeyList   = MosUtilitiesSpecificNext::m_ufKeyList;
 
     switch((uintptr_t)UFKey)
     {
@@ -1201,13 +1180,6 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureGetKeyNamebyId(void  *UFKey, cha
         eStatus = MOS_STATUS_SUCCESS;
         break;
     default:
-        if ((eStatus = UserFeatureDumpFile(m_szUserFeatureFile, &pKeyList)) !=
-            MOS_STATUS_SUCCESS )
-        {
-            UserFeatureFreeKeyList(pKeyList);
-            return eStatus;
-        }
-
         eStatus   = MOS_STATUS_UNKNOWN;
 
         for(pTempNode=pKeyList;pTempNode;pTempNode=pTempNode->pNext)
@@ -1219,7 +1191,6 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureGetKeyNamebyId(void  *UFKey, cha
                 break;
             }
         }
-        UserFeatureFreeKeyList(pKeyList);
         break;
     }
 
@@ -1363,7 +1334,7 @@ MOS_STATUS MosUtilities::MosOsUtilitiesInit(MOS_CONTEXT_HANDLE mosCtx)
     {
         //Init MOS User Feature Key from mos desc table
         eStatus = MosDeclareUserFeatureKeysForAllDescFields();
-
+        MosUtilitiesSpecificNext::UserFeatureDumpFile(MosUtilitiesSpecificNext::m_szUserFeatureFile, &MosUtilitiesSpecificNext::m_ufKeyList);
 #if _MEDIA_RESERVED
         m_codecUserFeatureExt = new CodechalUserSettingsMgr();
         m_vpUserFeatureExt    = new VphalUserSettingsMgr();
@@ -1397,6 +1368,7 @@ MOS_STATUS MosUtilities::MosOsUtilitiesClose(MOS_CONTEXT_HANDLE mosCtx)
     if (m_mosUtilInitCount == 0)
     {
         MosTraceEventClose();
+        DestroyMediaUserSetting();
         m_mosMemAllocCounter -= m_mosMemAllocFakeCounter;
         MemoryCounter = m_mosMemAllocCounter + m_mosMemAllocCounterGfx;
         m_mosMemAllocCounterNoUserFeature    = m_mosMemAllocCounter;
@@ -1425,6 +1397,9 @@ MOS_STATUS MosUtilities::MosOsUtilitiesClose(MOS_CONTEXT_HANDLE mosCtx)
         // so if there still is another active lib instance, logs would still be printed.
         MosUtilDebug::MosMessageClose();
 #endif
+        MosUtilitiesSpecificNext::UserFeatureDumpDataToFile(MosUtilitiesSpecificNext::m_szUserFeatureFile, MosUtilitiesSpecificNext::m_ufKeyList);
+        MosUtilitiesSpecificNext::UserFeatureFreeKeyList(MosUtilitiesSpecificNext::m_ufKeyList);
+        MosUtilitiesSpecificNext::m_ufKeyList = nullptr;
     }
     m_mutexLock.Unlock();
     return eStatus;
@@ -1664,6 +1639,32 @@ MOS_STATUS MosUtilities::MosCloseRegKey(
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS MosUtilities::MosReadEnvVariable(
+    UFKEY_NEXT keyHandle,
+    const std::string &valueName,
+    uint32_t *type,
+    std::string &data,
+    uint32_t *size)
+{
+    MOS_OS_CHK_NULL_RETURN(size);
+    MOS_UNUSED(type);
+
+    MOS_STATUS status = MOS_STATUS_SUCCESS;
+
+    std::string name = valueName;
+    std::replace(name.begin(), name.end(), ' ', '_');
+    char *retVal = getenv(name.c_str());
+    if (retVal != nullptr)
+    {
+        std::string strData = retVal;
+        *size               = strData.length();
+        data                = strData;
+        return MOS_STATUS_SUCCESS;
+    }
+
+    return MOS_STATUS_INVALID_PARAMETER;
+}
+
 MOS_STATUS MosUtilities::MosGetRegValue(
     UFKEY_NEXT keyHandle,
     const std::string &valueName,
@@ -1685,18 +1686,6 @@ MOS_STATUS MosUtilities::MosGetRegValue(
 
     try
     {
-        // Read the value from ENV. variable as first
-        std::string name = valueName;
-        std::replace(name.begin(),name.end(),' ','_');
-        char* retVal = getenv(name.c_str());
-        if (retVal != nullptr)
-        {
-            std::string strData = retVal;
-            *size = strData.length();
-            data = strData;
-            return MOS_STATUS_SUCCESS;
-        }
-
         auto keys = util::m_regBuffer[keyHandle];
         auto it = keys.find(valueName);
         if (it == keys.end())
@@ -1959,66 +1948,40 @@ MOS_STATUS MosUtilities::MosReadApoDdiEnabledUserFeature(uint32_t &userfeatureVa
 MOS_STATUS MosUtilities::MosReadApoMosEnabledUserFeature(uint32_t &userfeatureValue, char *path)
 {
     MOS_STATUS eStatus  = MOS_STATUS_SUCCESS;
-    void *     UFKey    = nullptr;
-    uint32_t   dwUFSize = 0;
-    uint32_t   data     = 0;
+    MOS_USER_FEATURE_VALUE_DATA userFeatureData     = {};
     MOS_UNUSED(path);
 
-#if (_DEBUG || _RELEASE_INTERNAL)
-    eStatus = MosGetApoMosEnabledUserFeatureFile();
-#endif
-
-    eStatus = MosUserFeatureOpen(
-        MOS_USER_FEATURE_TYPE_USER,
-        __MEDIA_USER_FEATURE_SUBKEY_INTERNAL,
-        KEY_READ,
-        &UFKey,
-        nullptr);
-
-    if (eStatus != MOS_STATUS_SUCCESS)
-    {
-        MOS_OS_NORMALMESSAGE("Failed to open ApoMosEnable user feature key , error status %d.", eStatus);
-        return eStatus;
-    }
-
     //If apo mos enabled, to check if media solo is enabled. Disable apo mos if media solo is enabled.
 #if MOS_MEDIASOLO_SUPPORTED
-    eStatus = MosUserFeatureGetValue(
-        UFKey,
-        nullptr,
-        __MEDIA_USER_FEATURE_VALUE_MEDIASOLO_ENABLE,
-        RRF_RT_UF_DWORD,
-        nullptr,
-        &data,
-        &dwUFSize);
+    eStatus = MosUtilities::MosUserFeatureReadValueID(
+            nullptr,
+            __MEDIA_USER_FEATURE_VALUE_MEDIASOLO_ENABLE_ID,
+            &userFeatureData,
+            (MOS_CONTEXT_HANDLE) nullptr);
 
     //If media solo is enabled, disable apogeios.
-    if (eStatus == MOS_STATUS_SUCCESS && data > 0)
+    if (eStatus == MOS_STATUS_SUCCESS && userFeatureData.i32Data != 0)
     {
         // This error case can be hit if the user feature key does not exist.
         MOS_OS_NORMALMESSAGE("Solo is enabled, disable apo mos");
         userfeatureValue = 0;
-        MosUserFeatureCloseKey(UFKey);  // Closes the key if not nullptr
         return MOS_STATUS_SUCCESS;
     }
 #endif
 
-    eStatus = MosUserFeatureGetValue(
-        UFKey,
-        nullptr,
-        "ApoMosEnable",
-        RRF_RT_UF_DWORD,
-        nullptr,
-        &userfeatureValue,
-        &dwUFSize);
+    MosUtilities::MosZeroMemory(&userFeatureData, sizeof(userFeatureData));
+    eStatus = MosUtilities::MosUserFeatureReadValueID(
+            nullptr,
+            __MEDIA_USER_FEATURE_VALUE_APO_MOS_PATH_ENABLE_ID,
+            &userFeatureData,
+            (MOS_CONTEXT_HANDLE) nullptr);
 
     if (eStatus != MOS_STATUS_SUCCESS)
     {
-        // This error case can be hit if the user feature key does not exist.
+        // It could be there is no this use feature key.
         MOS_OS_NORMALMESSAGE("Failed to read ApoMosEnable  user feature key value, error status %d", eStatus);
     }
-
-    MosUserFeatureCloseKey(UFKey);  // Closes the key if not nullptr
+    userfeatureValue = userFeatureData.u32Data ? true : false;
     return eStatus;
 }
 
@@ -2316,13 +2279,13 @@ uint32_t MosUtilities::MosWaitForMultipleObjects(
 int32_t MosUtilities::MosAtomicIncrement(
     int32_t *pValue)
 {
-    return __sync_fetch_and_add(pValue, 1);
+    return __sync_add_and_fetch(pValue, 1);
 }
 
 int32_t MosUtilities::MosAtomicDecrement(
     int32_t *pValue)
 {
-    return __sync_fetch_and_sub(pValue, 1);
+    return __sync_sub_and_fetch(pValue, 1);
 }
 
 VAStatus MosUtilities::MosStatusToOsResult(
@@ -2402,6 +2365,11 @@ void MosUtilities::MosTraceSetupInfo(uint32_t DrvVer, uint32_t PlatFamily, uint3
     // not implemented
 }
 
+uint64_t MosUtilities::GetTraceEventKeyword()
+{
+    return 0;
+}
+
 #define TRACE_EVENT_MAX_SIZE    (1024)
 #define TRACE_EVENT_HEADER_SIZE (sizeof(uint32_t)*3)
 void MosUtilities::MosTraceEvent(
